Variable Explorer
=================

The variable explorer shows the namespace contents (i.e. all global object
references) of the current console

|

.. image:: images/variableexplorer1.png
   :align: center

|

The following screenshots show some interesting features such as editing 
lists, strings, dictionaries, NumPy arrays, or plotting/showing NumPy arrays
data.

|

.. image:: images/listeditor.png
   :align: center

|

.. image:: images/texteditor.png
   :align: center

|

.. image:: images/dicteditor.png
   :align: center

|

.. image:: images/arrayeditor.png
   :align: center

|

.. image:: images/variableexplorer-plot.png
   :align: center

|

.. image:: images/variableexplorer-imshow.png
   :align: center

|


Supported types
---------------

The variable explorer can't show all types of objects. The ones currently
supported are:

#. `Pandas` DataFrame, TimeSeries and DatetimeIndex objects
#. `NumPy` arrays and matrices
#. `PIL/Pillow` images
#. `datetime` dates
#. Integers
#. Floats
#. Complex numbers
#. Lists
#. Dictionaries
#. Tuples
#. Strings

Related plugins:

* :doc:`ipythonconsole`
